.. ecco_access documentation index file, adapted from the
   equivalent file for the ECCO Version 4 Python Tutorial 
   (https://github.com/ECCO-GROUP/ECCO-v4-Python-Tutorial), created by
   sphinx-quickstart on Mon Jan 22 20:58:25 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to ecco_access!
======================================

*ecco_access* is a Python package with utilities for accessing output from the Estimating the Circulation and Climate of the Ocean (ECCO) state estimate. These tools enable the user to query and download ECCO output to their local machine, or directly access the ECCO output when working in the AWS Cloud.

If you have any questions, suggestions, or would like to contribute to `ecco_access`, please reach out to andrewdelman@ucla.edu. Thank you!

.. toctree::
   :maxdepth: 2
   :caption: Introduction and Setup

   intro
   ECCO_output_on_NASA_Earthdata.ipynb
   Installation

.. toctree::
   :maxdepth: 2
   :caption: Notebook Tutorials

   Using_ECCO_access.ipynb
   ECCO_access_modes.ipynb
   Querying_ECCO_variables.ipynb
   ECCO_access_subsets.ipynb
   ECCO_access_v4r5.ipynb

.. toctree::
   :maxdepth: 2
   :caption: Miscellaneous
   
   Downloading_ECCO_Datasets_with_wget.md

.. toctree::
   :maxdepth: 2
   :caption: API
   
.. toctree::
   :maxdepth: 2
   :caption: Support 

   support

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
